# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2
from cogneed_protos.ai.cogneed.api.modelconfig import keyword_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2


class KeywordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Create = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.keyword.KeywordService/Create',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.CreateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.List = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.keyword.KeywordService/List',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.ListRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.ListResponse.FromString,
        )
    self.UpdateUsage = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.keyword.KeywordService/UpdateUsage',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.UpdateUsageRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/ai.cogneed.api.modelconfig.keyword.KeywordService/Delete',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.DeleteRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.FromString,
        )


class KeywordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Create(self, request, context):
    """create a new keyword for the given model.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def List(self, request, context):
    """list all keywords for the given model.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateUsage(self, request, context):
    """update information from a keyword for the given model.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    """delete a given keyword for the given model.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Create': grpc.unary_unary_rpc_method_handler(
          servicer.Create,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.CreateRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'List': grpc.unary_unary_rpc_method_handler(
          servicer.List,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.ListRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.ListResponse.SerializeToString,
      ),
      'UpdateUsage': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateUsage,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.UpdateUsageRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_modelconfig_dot_keyword__pb2.DeleteRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.AckResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.modelconfig.keyword.KeywordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.opus_decoder import opus_decoder_service_pb2 as cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2


class OpusDecoderServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.convert = channel.unary_unary(
        '/ai.cogneed.cloud.speech.v1.OpusDecoderService/convert',
        request_serializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeResponse.FromString,
        )


class OpusDecoderServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def convert(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OpusDecoderServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'convert': grpc.unary_unary_rpc_method_handler(
          servicer.convert,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_opus__decoder_dot_opus__decoder__service__pb2.DecodeResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.OpusDecoderService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.trainui import sentence_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2
from cogneed_protos.ai.cogneed.api.trainui import tasks_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2


class TasksServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get_progress = channel.unary_unary(
        '/ai.cogneed.api.trainui.tasks.TasksService/get_progress',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.TaskRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.Progress.FromString,
        )
    self.get_next = channel.unary_unary(
        '/ai.cogneed.api.trainui.tasks.TasksService/get_next',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.TaskRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2.Sentence.FromString,
        )


class TasksServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get_progress(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_next(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TasksServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get_progress': grpc.unary_unary_rpc_method_handler(
          servicer.get_progress,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.TaskRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.Progress.SerializeToString,
      ),
      'get_next': grpc.unary_unary_rpc_method_handler(
          servicer.get_next,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_tasks__pb2.TaskRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_trainui_dot_sentence__pb2.Sentence.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.trainui.tasks.TasksService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/trainui/config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/trainui/config.proto',
  package='ai.cogneed.api.trainui.config',
  syntax='proto3',
  serialized_options=_b('\n\035ai.cogneed.api.trainui.configP\001'),
  serialized_pb=_b('\n2cogneed-protos/ai/cogneed/api/trainui/config.proto\x12\x1d\x61i.cogneed.api.trainui.config\x1a*cogneed-protos/ai/cogneed/api/common.proto\"\xa3\x01\n\x06\x43onfig\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\ruse_case_uuid\x18\x02 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\x05\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_at\x18\x08 \x01(\x03\"K\n\x0cUpdateTarget\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\x05\":\n\x0bReadRequest\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t2\xbe\x01\n\rConfigService\x12Y\n\x04read\x12*.ai.cogneed.api.trainui.config.ReadRequest\x1a%.ai.cogneed.api.trainui.config.Config\x12R\n\x06update\x12+.ai.cogneed.api.trainui.config.UpdateTarget\x1a\x1b.ai.cogneed.api.AckResponseB!\n\x1d\x61i.cogneed.api.trainui.configP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='ai.cogneed.api.trainui.config.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.trainui.config.Config.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.Config.use_case_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.Config.keyword_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.config.Config.target', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.trainui.config.Config.created_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.trainui.config.Config.updated_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.trainui.config.Config.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.trainui.config.Config.updated_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=293,
)


_UPDATETARGET = _descriptor.Descriptor(
  name='UpdateTarget',
  full_name='ai.cogneed.api.trainui.config.UpdateTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.UpdateTarget.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.UpdateTarget.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='ai.cogneed.api.trainui.config.UpdateTarget.target', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=370,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='ai.cogneed.api.trainui.config.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.trainui.config.ReadRequest.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.trainui.config.ReadRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=430,
)

DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.message_types_by_name['UpdateTarget'] = _UPDATETARGET
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), dict(
  DESCRIPTOR = _CONFIG,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.Config)
  ))
_sym_db.RegisterMessage(Config)

UpdateTarget = _reflection.GeneratedProtocolMessageType('UpdateTarget', (_message.Message,), dict(
  DESCRIPTOR = _UPDATETARGET,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.UpdateTarget)
  ))
_sym_db.RegisterMessage(UpdateTarget)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), dict(
  DESCRIPTOR = _READREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.trainui.config_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.trainui.config.ReadRequest)
  ))
_sym_db.RegisterMessage(ReadRequest)


DESCRIPTOR._options = None

_CONFIGSERVICE = _descriptor.ServiceDescriptor(
  name='ConfigService',
  full_name='ai.cogneed.api.trainui.config.ConfigService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=433,
  serialized_end=623,
  methods=[
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.trainui.config.ConfigService.read',
    index=0,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=_CONFIG,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='update',
    full_name='ai.cogneed.api.trainui.config.ConfigService.update',
    index=1,
    containing_service=None,
    input_type=_UPDATETARGET,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIGSERVICE)

DESCRIPTOR.services_by_name['ConfigService'] = _CONFIGSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto',
  package='ai.cogneed.api.predict.eval',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.predict.evalP\001'),
  serialized_pb=_b('\n@cogneed-protos/ai/cogneed/api/predict/eval/eval_prediction.proto\x12\x1b\x61i.cogneed.api.predict.eval\x1a*cogneed-protos/ai/cogneed/api/common.proto\"6\n\x11\x45valuationMetrics\x12\x11\n\tprecision\x18\x01 \x01(\x02\x12\x0e\n\x06recall\x18\x02 \x01(\x02\"p\n\nSetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\x12=\n\x05value\x18\x03 \x01(\x0b\x32..ai.cogneed.api.predict.eval.EvaluationMetrics\"1\n\nGetRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"M\n\x0bGetResponse\x12>\n\x06result\x18\x01 \x01(\x0b\x32..ai.cogneed.api.predict.eval.EvaluationMetrics2\xbb\x01\n\x12PredictEvalService\x12X\n\x03Get\x12\'.ai.cogneed.api.predict.eval.GetRequest\x1a(.ai.cogneed.api.predict.eval.GetResponse\x12K\n\x03Set\x12\'.ai.cogneed.api.predict.eval.SetRequest\x1a\x1b.ai.cogneed.api.AckResponseB\x1f\n\x1b\x61i.cogneed.api.predict.evalP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_EVALUATIONMETRICS = _descriptor.Descriptor(
  name='EvaluationMetrics',
  full_name='ai.cogneed.api.predict.eval.EvaluationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='precision', full_name='ai.cogneed.api.predict.eval.EvaluationMetrics.precision', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recall', full_name='ai.cogneed.api.predict.eval.EvaluationMetrics.recall', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=195,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='ai.cogneed.api.predict.eval.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.eval.SetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.eval.SetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ai.cogneed.api.predict.eval.SetRequest.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=309,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ai.cogneed.api.predict.eval.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.predict.eval.GetRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.eval.GetRequest.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=360,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ai.cogneed.api.predict.eval.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ai.cogneed.api.predict.eval.GetResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=439,
)

_SETREQUEST.fields_by_name['value'].message_type = _EVALUATIONMETRICS
_GETRESPONSE.fields_by_name['result'].message_type = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['EvaluationMetrics'] = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EvaluationMetrics = _reflection.GeneratedProtocolMessageType('EvaluationMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATIONMETRICS,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.EvaluationMetrics)
  ))
_sym_db.RegisterMessage(EvaluationMetrics)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.eval.eval_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.eval.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None

_PREDICTEVALSERVICE = _descriptor.ServiceDescriptor(
  name='PredictEvalService',
  full_name='ai.cogneed.api.predict.eval.PredictEvalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=442,
  serialized_end=629,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='ai.cogneed.api.predict.eval.PredictEvalService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='ai.cogneed.api.predict.eval.PredictEvalService.Set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTEVALSERVICE)

DESCRIPTOR.services_by_name['PredictEvalService'] = _PREDICTEVALSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto',
  package='ai.cogneed.api.predict.bulk',
  syntax='proto3',
  serialized_options=_b('\n\033ai.cogneed.api.predict.bulkP\001'),
  serialized_pb=_b('\n@cogneed-protos/ai/cogneed/api/predict/bulk/bulk_prediction.proto\x12\x1b\x61i.cogneed.api.predict.bulk\"I\n\x14\x42ulkDetectionRequest\x12\x10\n\x08gcs_path\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\x12\r\n\x05major\x18\x03 \x01(\t\")\n\x18PredictDetectionResponse\x12\r\n\x05index\x18\x01 \x03(\t2\x91\x01\n\x14\x42ulkDetectionService\x12y\n\rGetDetections\x12\x31.ai.cogneed.api.predict.bulk.BulkDetectionRequest\x1a\x35.ai.cogneed.api.predict.bulk.PredictDetectionResponseB\x1f\n\x1b\x61i.cogneed.api.predict.bulkP\x01\x62\x06proto3')
)




_BULKDETECTIONREQUEST = _descriptor.Descriptor(
  name='BulkDetectionRequest',
  full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gcs_path', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.gcs_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.bulk.BulkDetectionRequest.major', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=170,
)


_PREDICTDETECTIONRESPONSE = _descriptor.Descriptor(
  name='PredictDetectionResponse',
  full_name='ai.cogneed.api.predict.bulk.PredictDetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='ai.cogneed.api.predict.bulk.PredictDetectionResponse.index', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=213,
)

DESCRIPTOR.message_types_by_name['BulkDetectionRequest'] = _BULKDETECTIONREQUEST
DESCRIPTOR.message_types_by_name['PredictDetectionResponse'] = _PREDICTDETECTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BulkDetectionRequest = _reflection.GeneratedProtocolMessageType('BulkDetectionRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKDETECTIONREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.bulk.bulk_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.bulk.BulkDetectionRequest)
  ))
_sym_db.RegisterMessage(BulkDetectionRequest)

PredictDetectionResponse = _reflection.GeneratedProtocolMessageType('PredictDetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTDETECTIONRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.predict.bulk.bulk_prediction_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.bulk.PredictDetectionResponse)
  ))
_sym_db.RegisterMessage(PredictDetectionResponse)


DESCRIPTOR._options = None

_BULKDETECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='BulkDetectionService',
  full_name='ai.cogneed.api.predict.bulk.BulkDetectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=216,
  serialized_end=361,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDetections',
    full_name='ai.cogneed.api.predict.bulk.BulkDetectionService.GetDetections',
    index=0,
    containing_service=None,
    input_type=_BULKDETECTIONREQUEST,
    output_type=_PREDICTDETECTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BULKDETECTIONSERVICE)

DESCRIPTOR.services_by_name['BulkDetectionService'] = _BULKDETECTIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto',
  package='ai.cogneed.api.modelconfig.keyword',
  syntax='proto3',
  serialized_options=_b('\n\"ai.cogneed.api.modelconfig.keywordP\001'),
  serialized_pb=_b('\n7cogneed-protos/ai/cogneed/api/modelconfig/keyword.proto\x12\"ai.cogneed.api.modelconfig.keyword\x1a*cogneed-protos/ai/cogneed/api/common.proto\"y\n\rCreateRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x02 \x01(\t\x12>\n\x05usage\x18\x03 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\"\xd6\x01\n\x0cKeywordUsage\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x12\n\nmodel_uuid\x18\x02 \x01(\t\x12\x14\n\x0ckeyword_uuid\x18\x03 \x01(\t\x12>\n\x05usage\x18\x04 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_at\x18\x08 \x01(\x03\"F\n\x0bListRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x15\n\rrows_per_page\x18\x03 \x01(\x05\"b\n\x12UpdateUsageRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12>\n\x05usage\x18\x02 \x01(\x0e\x32/.ai.cogneed.api.modelconfig.keyword.UsageOption\"\x1d\n\rDeleteRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"`\n\x0cListResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x41\n\x07results\x18\x02 \x03(\x0b\x32\x30.ai.cogneed.api.modelconfig.keyword.KeywordUsage*3\n\x0bUsageOption\x12\n\n\x06TARGET\x10\x00\x12\n\n\x06HELPER\x10\x01\x12\x0c\n\x08NEGATIVE\x10\x02\x32\x93\x03\n\x0eKeywordService\x12X\n\x06\x43reate\x12\x31.ai.cogneed.api.modelconfig.keyword.CreateRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12i\n\x04List\x12/.ai.cogneed.api.modelconfig.keyword.ListRequest\x1a\x30.ai.cogneed.api.modelconfig.keyword.ListResponse\x12\x62\n\x0bUpdateUsage\x12\x36.ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest\x1a\x1b.ai.cogneed.api.AckResponse\x12X\n\x06\x44\x65lete\x12\x31.ai.cogneed.api.modelconfig.keyword.DeleteRequest\x1a\x1b.ai.cogneed.api.AckResponseB&\n\"ai.cogneed.api.modelconfig.keywordP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])

_USAGEOPTION = _descriptor.EnumDescriptor(
  name='UsageOption',
  full_name='ai.cogneed.api.modelconfig.keyword.UsageOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TARGET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HELPER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGATIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=780,
  serialized_end=831,
)
_sym_db.RegisterEnumDescriptor(_USAGEOPTION)

UsageOption = enum_type_wrapper.EnumTypeWrapper(_USAGEOPTION)
TARGET = 0
HELPER = 1
NEGATIVE = 2



_CREATEREQUEST = _descriptor.Descriptor(
  name='CreateRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.keyword_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.CreateRequest.usage', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=260,
)


_KEYWORDUSAGE = _descriptor.Descriptor(
  name='KeywordUsage',
  full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.model_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_uuid', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.keyword_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.usage', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.created_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.updated_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.modelconfig.keyword.KeywordUsage.updated_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=477,
)


_LISTREQUEST = _descriptor.Descriptor(
  name='ListRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.ListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_uuid', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.model_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.page', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.modelconfig.keyword.ListRequest.rows_per_page', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=549,
)


_UPDATEUSAGEREQUEST = _descriptor.Descriptor(
  name='UpdateUsageRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest.usage', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=649,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='ai.cogneed.api.modelconfig.keyword.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.keyword.DeleteRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=651,
  serialized_end=680,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='ai.cogneed.api.modelconfig.keyword.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.modelconfig.keyword.ListResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='ai.cogneed.api.modelconfig.keyword.ListResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=778,
)

_CREATEREQUEST.fields_by_name['usage'].enum_type = _USAGEOPTION
_KEYWORDUSAGE.fields_by_name['usage'].enum_type = _USAGEOPTION
_UPDATEUSAGEREQUEST.fields_by_name['usage'].enum_type = _USAGEOPTION
_LISTRESPONSE.fields_by_name['results'].message_type = _KEYWORDUSAGE
DESCRIPTOR.message_types_by_name['CreateRequest'] = _CREATEREQUEST
DESCRIPTOR.message_types_by_name['KeywordUsage'] = _KEYWORDUSAGE
DESCRIPTOR.message_types_by_name['ListRequest'] = _LISTREQUEST
DESCRIPTOR.message_types_by_name['UpdateUsageRequest'] = _UPDATEUSAGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.enum_types_by_name['UsageOption'] = _USAGEOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRequest = _reflection.GeneratedProtocolMessageType('CreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.CreateRequest)
  ))
_sym_db.RegisterMessage(CreateRequest)

KeywordUsage = _reflection.GeneratedProtocolMessageType('KeywordUsage', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDUSAGE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.KeywordUsage)
  ))
_sym_db.RegisterMessage(KeywordUsage)

ListRequest = _reflection.GeneratedProtocolMessageType('ListRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.ListRequest)
  ))
_sym_db.RegisterMessage(ListRequest)

UpdateUsageRequest = _reflection.GeneratedProtocolMessageType('UpdateUsageRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUSAGEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.UpdateUsageRequest)
  ))
_sym_db.RegisterMessage(UpdateUsageRequest)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.keyword_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.keyword.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)


DESCRIPTOR._options = None

_KEYWORDSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordService',
  full_name='ai.cogneed.api.modelconfig.keyword.KeywordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=834,
  serialized_end=1237,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.List',
    index=1,
    containing_service=None,
    input_type=_LISTREQUEST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUsage',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.UpdateUsage',
    index=2,
    containing_service=None,
    input_type=_UPDATEUSAGEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='ai.cogneed.api.modelconfig.keyword.KeywordService.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDSERVICE)

DESCRIPTOR.services_by_name['KeywordService'] = _KEYWORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.ai.cogneed.api.predict.bulk import bulk_prediction_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2


class BulkDetectionServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetDetections = channel.unary_unary(
        '/ai.cogneed.api.predict.bulk.BulkDetectionService/GetDetections',
        request_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.BulkDetectionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.PredictDetectionResponse.FromString,
        )


class BulkDetectionServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetDetections(self, request, context):
    """get all detections from an audio file
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BulkDetectionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetDetections': grpc.unary_unary_rpc_method_handler(
          servicer.GetDetections,
          request_deserializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.BulkDetectionRequest.FromString,
          response_serializer=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_predict_dot_bulk_dot_bulk__prediction__pb2.PredictDetectionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.bulk.BulkDetectionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
